@@ -24,7 +24,6 @@
 
 #include <KDebug>
 
-#include <KIO/Scheduler>
 #include <KShell>
 #include <KIO/Job>
 
@@ -760,7 +759,7 @@ void Data_Provider::startDownloadData()
 		connect( jobc, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( jobc, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[0] = jobc;
-		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)jobc );
+		jobc->start();
 	}
 
 	if ( url1_prefix_xml != "" )
@@ -770,7 +769,7 @@ void Data_Provider::startDownloadData()
 		connect( job1, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job1, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[1] = job1;
-		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job1 );
+		job1->start();
 	}
 
 	if ( url2_prefix_xml != "" )
@@ -780,7 +779,7 @@ void Data_Provider::startDownloadData()
 		connect( job2, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job2, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[2] = job2;
-		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job2 );
+		job2->start();
 	}
 
 	if ( url3_prefix_xml != "" )
@@ -790,7 +789,7 @@ void Data_Provider::startDownloadData()
 		connect( job3, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job3, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[3] = job3;
-		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job3 );
+		job3->start();
 	}
 
 	if ( url4_prefix_xml != "" )
@@ -800,7 +799,7 @@ void Data_Provider::startDownloadData()
 		connect( job4, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job4, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[4] = job4;
-		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job4 );
+		job4->start();
 	}
 
 	if ( url5_prefix_xml != "" )
@@ -810,7 +809,7 @@ void Data_Provider::startDownloadData()
 		connect( job5, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job5, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[5] = job5;
-		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job5 );
+		job5->start();
 	}
 
 	if ( url6_prefix_xml != "" )
@@ -820,7 +819,7 @@ void Data_Provider::startDownloadData()
 		connect( job6, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job6, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[6] = job6;
-		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job6 );
+		job6->start();
 	}
 
 	if ( url7_prefix_xml != "" )
@@ -830,7 +829,7 @@ void Data_Provider::startDownloadData()
 		connect( job7, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job7, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[7] = job7;
-		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job7 );
+		job7->start();
 	}
 }
 
@@ -876,7 +875,7 @@ void Data_Provider::parseData()
 					connect( jobc, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( jobc, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[0] = jobc;
-					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)jobc );
+					jobc->start();
 				}
 
 				if ( url1_follow_xml != "" )
@@ -887,7 +886,7 @@ void Data_Provider::parseData()
 					connect( job1, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( job1, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[1] = job1;
-					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job1 );
+					job1->start();
 				}
 
 				if ( url2_follow_xml != "" )
@@ -898,7 +897,7 @@ void Data_Provider::parseData()
 					connect( job2, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( job2, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[2] = job2;
-					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job2 );
+					job2->start();
 				}
 
 				if ( url3_follow_xml != "" )
@@ -909,7 +908,7 @@ void Data_Provider::parseData()
 					connect( job3, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( job3, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[3] = job3;
-					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job3 );
+					job3->start();
 				}
 
 				if ( url4_follow_xml != "" )
@@ -920,7 +919,7 @@ void Data_Provider::parseData()
 					connect( job4, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( job4, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[4] = job4;
-					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job4 );
+					job4->start();
 				}
 
 				if ( url5_follow_xml != "" )
@@ -931,7 +930,7 @@ void Data_Provider::parseData()
 					connect( job5, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( job5, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[5] = job5;
-					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job5 );
+					job5->start();
 				}
 
 				if ( url6_follow_xml != "" )
@@ -942,7 +941,7 @@ void Data_Provider::parseData()
 					connect( job6, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( job6, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[6] = job6;
-					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job6 );
+					job6->start();
 				}
 
 				if ( url7_follow_xml != "" )
@@ -953,7 +952,7 @@ void Data_Provider::parseData()
 					connect( job7, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( job7, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[7] = job7;
-					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job7 );
+					job7->start();
 				}
 
 				return;
@@ -1057,7 +1056,7 @@ void Data_Provider::parseData()
 				connect( job_image, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( imageDownloadedData( KIO::Job *, const QByteArray & ) ) );
 				connect( job_image, SIGNAL( result( KJob * ) ), this, SLOT( imageDownloadFinished( KJob * ) ) );
 				image_job_list[i] = job_image;
-				KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job_image );
+				job_image->start();
 			}
 		}
 		if ( !job_started )
@@ -1159,7 +1158,7 @@ void Data_Provider::parseData()
 	connect( job_icon, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( iconDownloadedData( KIO::Job *, const QByteArray & ) ) );
 	connect( job_icon, SIGNAL( result( KJob * ) ), this, SLOT( iconDownloadFinished( KJob * ) ) );
 	icon_job_list[0] = job_icon;
-	KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job_icon );
+	job_icon->start();
 	for ( i=0; i<7; i++ )
 	{
 		icon_job_success_list[i+1] = false;
@@ -1167,7 +1166,7 @@ void Data_Provider::parseData()
 		connect( job_icon, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( iconDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job_icon, SIGNAL( result( KJob * ) ), this, SLOT( iconDownloadFinished( KJob * ) ) );
 		icon_job_list[i+1] = job_icon;
-		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job_icon );
+		job_icon->start();
 	}
 
 	data_update_time = KGlobal::locale()->formatTime( QTime::currentTime(), false, false );
@@ -1176,7 +1175,7 @@ void Data_Provider::parseData()
 	if ( !data_current_temperature.contains(QRegExp( "[0-9]" )) || data_current_temperature.length() > 6 /* too long temperature string? -21.5 has length=5 */ )
 	{
 		qDebug() << "Current temperature is invalid: Download didn't fail, but (all?) values are obviously invalid.";
-		data_update_time = "";
+//		data_update_time = "";
 	}
 
 	emit ( data_fetched() );
